# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sigstore_verification.proto

require 'google/protobuf'

require 'sigstore_common_pb'
require 'sigstore_trustroot_pb'
require 'sigstore_bundle_pb'


descriptor_data = "\n\x1bsigstore_verification.proto\x12\x1c\x64\x65v.sigstore.verification.v1\x1a\x15sigstore_common.proto\x1a\x18sigstore_trustroot.proto\x1a\x15sigstore_bundle.proto\"\xa3\x01\n\x13\x43\x65rtificateIdentity\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12;\n\x03san\x18\x02 \x01(\x0b\x32..dev.sigstore.common.v1.SubjectAlternativeName\x12?\n\x04oids\x18\x03 \x03(\x0b\x32\x31.dev.sigstore.common.v1.ObjectIdentifierValuePair\"^\n\x15\x43\x65rtificateIdentities\x12\x45\n\nidentities\x18\x01 \x03(\x0b\x32\x31.dev.sigstore.verification.v1.CertificateIdentity\"M\n\x13PublicKeyIdentities\x12\x36\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32!.dev.sigstore.common.v1.PublicKey\"\xaa\t\n\x1b\x41rtifactVerificationOptions\x12U\n\x16\x63\x65rtificate_identities\x18\x01 \x01(\x0b\x32\x33.dev.sigstore.verification.v1.CertificateIdentitiesH\x00\x12H\n\x0bpublic_keys\x18\x02 \x01(\x0b\x32\x31.dev.sigstore.verification.v1.PublicKeyIdentitiesH\x00\x12`\n\x0ctlog_options\x18\x03 \x01(\x0b\x32\x45.dev.sigstore.verification.v1.ArtifactVerificationOptions.TlogOptionsH\x01\x88\x01\x01\x12\x62\n\rctlog_options\x18\x04 \x01(\x0b\x32\x46.dev.sigstore.verification.v1.ArtifactVerificationOptions.CtlogOptionsH\x02\x88\x01\x01\x12m\n\x0btsa_options\x18\x05 \x01(\x0b\x32S.dev.sigstore.verification.v1.ArtifactVerificationOptions.TimestampAuthorityOptionsH\x03\x88\x01\x01\x12|\n\x15integrated_ts_options\x18\x06 \x01(\x0b\x32X.dev.sigstore.verification.v1.ArtifactVerificationOptions.TlogIntegratedTimestampOptionsH\x04\x88\x01\x01\x12q\n\x10observer_options\x18\x07 \x01(\x0b\x32R.dev.sigstore.verification.v1.ArtifactVerificationOptions.ObserverTimestampOptionsH\x05\x88\x01\x01\x1aV\n\x0bTlogOptions\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12#\n\x1bperform_online_verification\x18\x02 \x01(\x08\x12\x0f\n\x07\x64isable\x18\x03 \x01(\x08\x1a\x38\n\x0c\x43tlogOptions\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07\x64isable\x18\x03 \x01(\x08J\x04\x08\x02\x10\x03\x1a?\n\x19TimestampAuthorityOptions\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x1a\x44\n\x1eTlogIntegratedTimestampOptions\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x1a>\n\x18ObserverTimestampOptions\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07\x64isable\x18\x02 \x01(\x08\x42\t\n\x07signersB\x0f\n\r_tlog_optionsB\x10\n\x0e_ctlog_optionsB\x0e\n\x0c_tsa_optionsB\x18\n\x16_integrated_ts_optionsB\x13\n\x11_observer_options\"}\n\x08\x41rtifact\x12\x16\n\x0c\x61rtifact_uri\x18\x01 \x01(\tH\x00\x12\x12\n\x08\x61rtifact\x18\x02 \x01(\x0cH\x00\x12=\n\x0f\x61rtifact_digest\x18\x03 \x01(\x0b\x32\".dev.sigstore.common.v1.HashOutputH\x00\x42\x06\n\x04\x64\x61ta\"\xaa\x02\n\x05Input\x12\x43\n\x13\x61rtifact_trust_root\x18\x01 \x01(\x0b\x32&.dev.sigstore.trustroot.v1.TrustedRoot\x12`\n\x1d\x61rtifact_verification_options\x18\x02 \x01(\x0b\x32\x39.dev.sigstore.verification.v1.ArtifactVerificationOptions\x12.\n\x06\x62undle\x18\x03 \x01(\x0b\x32\x1e.dev.sigstore.bundle.v1.Bundle\x12=\n\x08\x61rtifact\x18\x04 \x01(\x0b\x32&.dev.sigstore.verification.v1.ArtifactH\x00\x88\x01\x01\x42\x0b\n\t_artifactB\x94\x01\n\"dev.sigstore.proto.verification.v1B\x11VerificationProtoP\x01Z<github.com/sigstore/protobuf-specs/gen/pb-go/verification/v1\xea\x02\x1aSigstore::Verification::V1b\x06proto3"

pool = Google::Protobuf::DescriptorPool.generated_pool
pool.add_serialized_file(descriptor_data)

module Sigstore
  module Verification
    module V1
      CertificateIdentity = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.CertificateIdentity").msgclass
      CertificateIdentities = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.CertificateIdentities").msgclass
      PublicKeyIdentities = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.PublicKeyIdentities").msgclass
      ArtifactVerificationOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions").msgclass
      ArtifactVerificationOptions::TlogOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions.TlogOptions").msgclass
      ArtifactVerificationOptions::CtlogOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions.CtlogOptions").msgclass
      ArtifactVerificationOptions::TimestampAuthorityOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions.TimestampAuthorityOptions").msgclass
      ArtifactVerificationOptions::TlogIntegratedTimestampOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions.TlogIntegratedTimestampOptions").msgclass
      ArtifactVerificationOptions::ObserverTimestampOptions = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.ArtifactVerificationOptions.ObserverTimestampOptions").msgclass
      Artifact = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.Artifact").msgclass
      Input = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.verification.v1.Input").msgclass
    end
  end
end
