# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sigstore_rekor.proto

require 'google/protobuf'

require 'google/api/field_behavior_pb'
require 'sigstore_common_pb'


descriptor_data = "\n\x14sigstore_rekor.proto\x12\x15\x64\x65v.sigstore.rekor.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x15sigstore_common.proto\"6\n\x0bKindVersion\x12\x11\n\x04kind\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07version\x18\x02 \x01(\tB\x03\xe0\x41\x02\"#\n\nCheckpoint\x12\x15\n\x08\x65nvelope\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xa9\x01\n\x0eInclusionProof\x12\x16\n\tlog_index\x18\x01 \x01(\x03\x42\x03\xe0\x41\x02\x12\x16\n\troot_hash\x18\x02 \x01(\x0c\x42\x03\xe0\x41\x02\x12\x16\n\ttree_size\x18\x03 \x01(\x03\x42\x03\xe0\x41\x02\x12\x13\n\x06hashes\x18\x04 \x03(\x0c\x42\x03\xe0\x41\x02\x12:\n\ncheckpoint\x18\x05 \x01(\x0b\x32!.dev.sigstore.rekor.v1.CheckpointB\x03\xe0\x41\x02\"7\n\x10InclusionPromise\x12#\n\x16signed_entry_timestamp\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x02\"\xe4\x02\n\x14TransparencyLogEntry\x12\x16\n\tlog_index\x18\x01 \x01(\x03\x42\x03\xe0\x41\x02\x12\x32\n\x06log_id\x18\x02 \x01(\x0b\x32\x1d.dev.sigstore.common.v1.LogIdB\x03\xe0\x41\x02\x12=\n\x0ckind_version\x18\x03 \x01(\x0b\x32\".dev.sigstore.rekor.v1.KindVersionB\x03\xe0\x41\x02\x12\x1c\n\x0fintegrated_time\x18\x04 \x01(\x03\x42\x03\xe0\x41\x02\x12\x42\n\x11inclusion_promise\x18\x05 \x01(\x0b\x32\'.dev.sigstore.rekor.v1.InclusionPromise\x12\x43\n\x0finclusion_proof\x18\x06 \x01(\x0b\x32%.dev.sigstore.rekor.v1.InclusionProofB\x03\xe0\x41\x02\x12\x1a\n\x12\x63\x61nonicalized_body\x18\x07 \x01(\x0c\x42x\n\x1b\x64\x65v.sigstore.proto.rekor.v1B\nRekorProtoP\x01Z5github.com/sigstore/protobuf-specs/gen/pb-go/rekor/v1\xea\x02\x13Sigstore::Rekor::V1b\x06proto3"

pool = Google::Protobuf::DescriptorPool.generated_pool
pool.add_serialized_file(descriptor_data)

module Sigstore
  module Rekor
    module V1
      KindVersion = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.KindVersion").msgclass
      Checkpoint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.Checkpoint").msgclass
      InclusionProof = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.InclusionProof").msgclass
      InclusionPromise = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.InclusionPromise").msgclass
      TransparencyLogEntry = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.TransparencyLogEntry").msgclass
    end
  end
end
